# Summary
*Introduction to the issue*

# Versions
 - ROS Driver version:
 - Affected Robot Software Version(s):
 - Affected Robot Hardware Version(s):
 - Robot Serial Number:
 - UR+ product(s) installed:
 - URCaps Software version(s):

# Impact
*What is the impact of the issue. Try to describe it well enough, in order for us to prioritise the issues.*


# Issue details
*This part is important in order to clarify the severity of the issue.*


## Use Case and Setup
*What does the setup look like and what are the objectives?*


## Project status at point of discovered
*When did you first observe the issue?*
 - *Before I started?*
 - *In first couple of tries?*
 - *In normal use?*
 - *etc...*


## Steps to Reproduce
*Make simple example to reproduce the issue. Try to remove dependencies to other hardware and software components, if it is possible.*


## Expected Behavior
*What did you expect and why?*


## Actual Behavior
*What did you observe? If possible please attach relevant information.*


## Workaround Suggestion
*If a workaround has been found, you are welcome to share.*
